@@ -2,13 +2,15 @@
 
 from __future__ import annotations
 from enum import Enum
+from functools import wraps
 from json import dumps
 from re import fullmatch
-from typing import Generator, Iterable, Iterator
+from typing import Callable, Generator, Iterable, Iterator
 
 
 __all__ = [
     'boolmap',
+    'parsed',
     'str_until_none',
     'stringify',
     'until_none'
@@ -31,6 +33,24 @@ def boolmap(text: str, true: str = None, false: str = None, *,
     return default
 
 
+def parsed(parser: Callable[[str], type]) -> Callable[[Callable], Callable]:
+    """Updates a function to parse its result with a parser."""
+
+    def decorator(function: Callable) -> Callable:
+        """Decorator that wraps the function and updates its return type."""
+        @wraps(function)
+        def inner(*args, **kwargs):
+            """Wrapper function thats parses the function's return value."""
+            return parser(function(*args, **kwargs))
+
+        if 'return' in parser.__annotations__:
+            inner.__annotations__['return'] = parser.__annotations__['return']
+
+        return inner
+
+    return decorator
+
+
 def str_until_none(*items: object) -> Iterator[str]:
     """Yields the items converted to str until one item is None."""
 
