@@ -1,8 +1,8 @@
 """Response types."""
 
-from mcipc.rcon.response_types.help import Command, Help
+from mcipc.rcon.response_types.kick import KickedPlayer
 from mcipc.rcon.response_types.location import Location
 from mcipc.rcon.response_types.players import Player, Players
 
 
-__all__ = ['Command', 'Help', 'Location', 'Player', 'Players']
+__all__ = ['KickedPlayer', 'Location', 'Player', 'Players']
